@@ -1,22 +1,9 @@
-/**
- This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
+/*
+    This file is part of Kig, a KDE program for Interactive Geometry...
+    SPDX-FileCopyrightText: 2002 Dominique Devriese <devriese@kde.org>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
- USA
-**/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kig.h"
 
@@ -31,6 +18,7 @@
 #include <QTimer>
 #include <QUrl>
 
+#include <kxmlgui_version.h>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KEditToolBar>
@@ -107,7 +95,12 @@ void Kig::setupActions()
   m_recentFilesAction = KStandardAction::openRecent( this, SLOT(openUrl(QUrl)), actionCollection() );
   m_recentFilesAction->loadEntries(config->group( QString() ) );
 
+#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+  KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
+#else
   KStandardAction::keyBindings( guiFactory(), SLOT(configureShortcuts()), actionCollection() );
+#endif
+
   KStandardAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
 
   KStandardAction::tipOfDay( this, SLOT(tipOfDay()), actionCollection() );
