@@ -1,22 +1,9 @@
-/**
- This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
+/*
+    This file is part of Kig, a KDE program for Interactive Geometry...
+    SPDX-FileCopyrightText: 2002 Dominique Devriese <devriese@kde.org>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
- USA
-**/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kig_part.h"
 
@@ -96,8 +83,8 @@ QStringList getDataFiles( const QString & folder )
   return dataFiles;
 }
 
-// export this library...
-K_PLUGIN_FACTORY( KigPartFactory, registerPlugin< KigPart >(); )
+// export this class from this library...
+K_PLUGIN_CLASS_WITH_JSON( KigPart, "kig_part.json")
 
 SetCoordinateSystemAction::SetCoordinateSystemAction(
   KigPart& d, KActionCollection* parent )
@@ -189,9 +176,6 @@ KigPart::KigPart( QWidget *parentWidget, QObject *parent,
   : KParts::ReadWritePart( parent ),
     mMode( 0 ), mRememberConstruction( 0 ), mdocument( new KigDocument() )
 {
-  // we need an instance
-  setComponentData( kigAboutData( "kig", I18N_NOOP( "KigPart" ) ) );
-
   mMode = new NormalMode( *this );
 
   // we need a widget, to actually show the document
