@@ -1,22 +1,9 @@
-/**
- This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
+/*
+    This file is part of Kig, a KDE program for Interactive Geometry...
+    SPDX-FileCopyrightText: 2002 Dominique Devriese <devriese@kde.org>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
- USA
-**/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 #ifndef KIGPART_H
@@ -85,19 +72,19 @@ protected:
   /**
    * load our internal document from m_file
    */
-  bool openFile() Q_DECL_OVERRIDE;
+  bool openFile() override;
 
   /**
    * save our internal document to m_file
    */
-  bool saveFile() Q_DECL_OVERRIDE;
+  bool saveFile() override;
 
   /**
    * KigPart cannot be safely destroyed if it's in a nested event loop
    * (construct mode). As a workaround, call this first so it can cancel the
    * construction.
    */
-  bool queryClose() Q_DECL_OVERRIDE;
+  bool queryClose() override;
 
 public:
   void emitStatusBarText( const QString& text );
