@@ -19,10 +19,10 @@ class PropertiesActionsProvider
   // easiest way to do it, and I'm too lazy to do it properly ;)
   std::vector<int> mprops[NormalModePopupObjects::NumberOfMenus];
 public:
-  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree ) Q_DECL_OVERRIDE;
+  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree ) override;
   bool executeAction( int menu, int& id, const std::vector<ObjectHolder*>& os,
                       NormalModePopupObjects& popup,
-                      KigPart& doc, KigWidget& w, NormalMode& m ) Q_DECL_OVERRIDE;
+                      KigPart& doc, KigWidget& w, NormalMode& m ) override;
 };
 
 #endif // PROPERTIESACTIONSPROVIDER_H
