@@ -1,22 +1,9 @@
-/**
-   This file is part of Kig, a KDE program for Interactive Geometry...
-   Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
+/*
+    This file is part of Kig, a KDE program for Interactive Geometry...
+    SPDX-FileCopyrightText: 2002 Dominique Devriese <devriese@kde.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
-   USA
-**/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "typesdialog.h"
 
@@ -98,11 +85,11 @@ public:
   virtual ~MacroListElement();
 
   Macro* getMacro() const { return mmacro; }
-  bool isMacro() const Q_DECL_OVERRIDE { return true; }
-  QString name() const Q_DECL_OVERRIDE;
-  QString description() const Q_DECL_OVERRIDE;
-  QString icon( bool canNull = false ) const Q_DECL_OVERRIDE;
-  QString type() const Q_DECL_OVERRIDE;
+  bool isMacro() const override { return true; }
+  QString name() const override;
+  QString description() const override;
+  QString icon( bool canNull = false ) const override;
+  QString type() const override;
 };
 
 MacroListElement::MacroListElement( Macro* m )
