@@ -46,11 +46,11 @@ public:
   Macro* macroFromIndex( const QModelIndex& index ) const;
 
   // reimplementations from QAbstractTableModel
-  int columnCount( const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-  QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
-  QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
-  QModelIndex index( int row, int column, const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE;
-  int rowCount( const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE;
+  int columnCount( const QModelIndex& parent = QModelIndex() ) const override;
+  QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override;
+  QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
+  QModelIndex index( int row, int column, const QModelIndex& parent = QModelIndex() ) const override;
+  int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
 };
 
 /**
