@@ -18,8 +18,8 @@ class CocConicType
   ~CocConicType();
 public:
   static const CocConicType* instance();
-  ObjectImp* calc( const Args& args, const KigDocument& ) const Q_DECL_OVERRIDE;
-  const ObjectImpType* resultId() const Q_DECL_OVERRIDE;
+  ObjectImp* calc( const Args& args, const KigDocument& ) const override;
+  const ObjectImpType* resultId() const override;
 };
 
 /**
@@ -33,8 +33,8 @@ class CocCubicType
   ~CocCubicType();
 public:
   static const CocCubicType* instance();
-  ObjectImp* calc( const Args& args, const KigDocument& ) const Q_DECL_OVERRIDE;
-  const ObjectImpType* resultId() const Q_DECL_OVERRIDE;
+  ObjectImp* calc( const Args& args, const KigDocument& ) const override;
+  const ObjectImpType* resultId() const override;
 };
 
 /**
@@ -48,8 +48,8 @@ class CocCurveType
   ~CocCurveType();
 public:
   static const CocCurveType* instance();
-  ObjectImp* calc( const Args& args, const KigDocument& ) const Q_DECL_OVERRIDE;
-  const ObjectImpType* resultId() const Q_DECL_OVERRIDE;
+  ObjectImp* calc( const Args& args, const KigDocument& ) const override;
+  const ObjectImpType* resultId() const override;
 };
 
 #endif
